@@ -30,11 +30,11 @@ namespace Rstats {
       return SvPV_nolen(sv);
     }
 
-    SV* new_sv_iv(I32 iv) {
+    SV* new_sv(I32 iv) {
       return sv_2mortal(newSViv(iv));
     }
 
-    SV* new_sv_uv(U32 uv) {
+    SV* new_sv(U32 uv) {
       return sv_2mortal(newSVuv(uv));
     }
     
@@ -42,14 +42,6 @@ namespace Rstats {
       return sv_2mortal(newSVsv(sv));
     }
     
-    SV* new_sv(int iv) {
-      return new_sv_iv((I32)iv);
-    }
-
-    SV* new_sv(unsigned int uv) {
-      return new_sv_uv((U32)uv);
-    }
-    
     SV* new_sv(double nv) {
       return sv_2mortal(newSVnv(nv));
     }
@@ -210,8 +202,8 @@ namespace Rstats {
     }
 
     template <class X> SV* to_perl_obj(X c_obj, char* class_name) {
-      size_t obj_addr = PTR2IV(c_obj);
-      SV* obj_addr_sv = new_sv_iv(obj_addr);
+      I32 obj_addr = PTR2IV(c_obj);
+      SV* obj_addr_sv = new_sv(obj_addr);
       SV* obj_addr_sv_ref = new_ref(obj_addr_sv);
       SV* perl_obj = sv_bless(obj_addr_sv_ref, gv_stashpv(class_name, 1));
       
